==> duiba-service-api-1.1-20160505.024441-10-sources.jar: cn/com/duiba/service/domain/dataobject/AppItemDO.java <==
package cn.com.duiba.service.domain.dataobject;

import cn.com.duiba.service.domain.BaseDO;

import java.util.Date;

public class AppItemDO extends BaseDO {
	public static final String StatusOn = "on";
	public static final String StatusOff = "off";
	public static final String SubStatusExpired = "expired"; // 子状态（expired：已过期）

	public static final String ExpressTypeFree = "free"; // 运费类型 包邮
	public static final String ExpressTypeUnity = "unity"; // 运费类型  统一运费
	public static final String ExpressTypeTemplate = "template"; // 运费类型 模板

	public static final int SourceTypeNormal = 0; // 普通兑换
	public static final int SourceTypeOperatingActivity = 1;// 运营活动创建的AppItem
	public static final int SourceTypeDuibaActivity = 2; //兑吧专题活动
	public static final int SourceTypeSingleLottery = 3;//单品抽奖活动
	public static final int SourceTypeManualLottery = 4;//手动开奖活动
	public static final int SourceTypeDuibaActivityItem = 5;// 专题活动的兑换项入口
	public static final int SourceTypeDuibaActivitySingleLottery = 6;// 专题活动的单品抽奖的兑换项入口
	public static final int SourceTypeAppShakeLottery = 7;//摇一摇抽奖
	public static final int SourceTypeAppScratchCardLottery = 8;//刮刮卡抽奖
	public static final int SourceTypeHdtoolTiger = 9;//老虎机
	public static final int SourceTypeHdtoolTurntable = 10;//活动工具大转盘
	public static final int SourceTypeSecondsKill = 11;//秒杀专题
	public static final int SourceTypeGameSanta = 20;//游戏，打劫圣诞老人
	public static final int SourceTypeGameYearAward = 21;//游戏，数年终奖
	public static final int SourceTypeGameGirl = 22;//游戏，数年终奖
	public static final int SourceTypeDuibaQuestionAnswer = 30;//兑吧答题活动
	public static final int SourceTypeDuibaQuizz = 41;//兑吧测试题活动
	public static final int SourceTypeDuibaSeckill = 40;//秒杀活动
	//会员等级限制类型,为0的话说明该兑换项没有配置会员等级限制
	public static final int OFF_LEVEL = 0;
	public static final int ACCURATE_LEVEL= 1;
	public static final int ABOVE_LEVEL = 2;

	private Long id;
	private Long appId;
	private Long itemId;
	private Long batchId;
	private Long credits;
	private Integer minFacePrice;
	private String logo;
	private String title;
	private String subtitle;
	private Integer payload ;
	private String customPrice; // 用户自定义商品价格（可分为1-6栏显示，存储结构为json形式的字符串，
						// 面值1:积分1,面值2:积分2...）
	private Date addTime; // 商品加入开发者库的时间。
	private Boolean deleted; // 是否已经删除
	private String status; // 状态（on/off）
	private String subStatus; // 子状态（）
	private Boolean homeDisplay;// 是否首页展示
	private Boolean isOwner; // 是否开发者发布

	private String exchangeTipTemplate;// 兑换提示模板 实物用于 兑换成功文案
	private String alertMessage;//实物用于 待发货文案

	// --以下为自有实物字段
	private String description;
	private Integer facePrice;
	private Integer limitCount;
	private Integer remaining;
	private Date validEndDate;
	private String smallImage;
	private String whiteImage;
	private String image;

	private String multiImage;
	private String type;// 商品类型，比如 QB，话费充值 等等

	private Integer sourceType; // 来源类型，目前有 普通兑换类型，运营活动类型
	private Long sourceRelationId;//
	
	private String limitScope;
	private Integer operationsType;
	private String limitTimeBetween;
	private Integer limitEverydayQuantity;
	private String bannerImage;
	
	private String limitDate; //兑换日期限制
	private String customTag;
	private Integer subType;

	private Date gmtCreate;
	private Date gmtModified;
	
	//会员等级限制添加字段
	private Long vipLimits;
	private Integer vipLimitType;
	
	private Date autoOffDate; //定时自动下架日期
	
	private String devCustomCode;	// 开发者的商品ID
	
	private Long salePrice;//	兑换价格		 
	private String expressType;//	运费类型		free(包邮)，unity(统一运费)，template(运费模板)
	private Long expressPrice;//	运费价格		选择 统一价 或者 包邮
	private Long expressTemplateId;//	运费模板ID	L	选择 模板
	
	
	
	public AppItemDO(boolean init4insert) {
		if (init4insert) {
			toBeInsert = true;
			facePrice = 0;
			isOwner = false;
			homeDisplay = true;
			deleted = false;
			sourceType = SourceTypeNormal;
			payload = 0;
			operationsType = 0;
			subStatus = "";
			gmtCreate = new Date();
			gmtModified = new Date();
			limitScope = ItemDO.LimitTypeForever;
			vipLimits = 0L;
			vipLimitType = 0;
		}
	}

	public AppItemDO(Long id) {
		this.id = id;
		this.gmtModified = new Date();
		toBeUpdate = true;
	}

	public AppItemDO() {
	}

	public void beforeUpdate() {
		gmtModified = new Date();
	}
	
	public void grantOpTypeAppItem(int opType){
		int v=1<<opType;
		operationsType=operationsType | v;
	}
	
	public void ungrantOpTypeAppItem(int opType){
		int v=1<<opType;
		v=~v;
		operationsType=operationsType & v;
	}
	
	public boolean isOpTypeAppItem(int opType){
		int v=1<<opType;
		int ret= operationsType & v;
		return ret!=0;
	}
	
	public String getAlertMessage() {
		return alertMessage;
	}

	public void setAlertMessage(String alertMessage) {
		this.alertMessage = alertMessage;
	}

	public Long getId() {
		return id;
	}
	public void setId(Long id) {
		this.id = id;
	}
	public Long getAppId() {
		return appId;
	}
	public void setAppId(Long appId) {
		this.appId = appId;
	}
	public Long getItemId() {
		return itemId;
	}
	public void setItemId(Long itemId) {
		this.itemId = itemId;
	}
	public Long getBatchId() {
		return batchId;
	}
	public void setBatchId(Long batchId) {
		this.batchId = batchId;
	}
	public Long getCredits() {
		return credits;
	}
	public void setCredits(Long credits) {
		this.credits = credits;
	}
	public Integer getMinFacePrice() {
		return minFacePrice;
	}
	public void setMinFacePrice(Integer minFacePrice) {
		this.minFacePrice = minFacePrice;
	}
	public String getLogo() {
		return logo;
	}
	public void setLogo(String logo) {
		this.logo = logo;
	}
	public String getTitle() {
		return title;
	}
	public void setTitle(String title) {
		this.title = title;
	}
	public String getSubtitle() {
		return subtitle;
	}
	public void setSubtitle(String subtitle) {
		this.subtitle = subtitle;
	}
	public Integer getPayload() {
		return payload;
	}
	public void setPayload(Integer payload) {
		this.payload = payload;
	}
	public String getCustomPrice() {
		return customPrice;
	}
	public void setCustomPrice(String customPrice) {
		this.customPrice = customPrice;
	}
	public Date getAddTime() {
		return addTime;
	}
	public void setAddTime(Date addTime) {
		this.addTime = addTime;
	}
	public Boolean getDeleted() {
		return deleted;
	}
	public void setDeleted(Boolean deleted) {
		this.deleted = deleted;
	}
	public String getStatus() {
		return status;
	}
	public void setStatus(String status) {
		this.status = status;
	}
	public String getSubStatus() {
		return subStatus;
	}
	public void setSubStatus(String subStatus) {
		this.subStatus = subStatus;
	}
	public Boolean getHomeDisplay() {
		return homeDisplay;
	}
	public void setHomeDisplay(Boolean homeDisplay) {
		this.homeDisplay = homeDisplay;
	}
	public Boolean getIsOwner() {
		return isOwner;
	}
	public void setIsOwner(Boolean isOwner) {
		this.isOwner = isOwner;
	}
	public String getExchangeTipTemplate() {
		return exchangeTipTemplate;
	}
	public void setExchangeTipTemplate(String exchangeTipTemplate) {
		this.exchangeTipTemplate = exchangeTipTemplate;
	}
	public String getDescription() {
		return description;
	}
	public void setDescription(String description) {
		this.description = description;
	}
	public Integer getFacePrice() {
		return facePrice;
	}
	public void setFacePrice(Integer facePrice) {
		this.facePrice = facePrice;
	}
	public Integer getLimitCount() {
		return limitCount;
	}
	public void setLimitCount(Integer limitCount) {
		this.limitCount = limitCount;
	}
	public Integer getRemaining() {
		return remaining;
	}
	public void setRemaining(Integer remaining) {
		this.remaining = remaining;
	}
	public Date getValidEndDate() {
		return validEndDate;
	}
	public void setValidEndDate(Date validEndDate) {
		this.validEndDate = validEndDate;
	}
	public String getSmallImage() {
		return smallImage;
	}
	public void setSmallImage(String smallImage) {
		this.smallImage = smallImage;
	}
	public String getImage() {
		return image;
	}
	public void setImage(String image) {
		this.image = image;
	}
	public String getMultiImage() {
		return multiImage;
	}
	public void setMultiImage(String multiImage) {
		this.multiImage = multiImage;
	}
	public String getType() {
		return type;
	}
	public void setType(String type) {
		this.type = type;
	}
	public Integer getSourceType() {
		return sourceType;
	}
	public void setSourceType(Integer sourceType) {
		this.sourceType = sourceType;
	}
	public Long getSourceRelationId() {
		return sourceRelationId;
	}
	public void setSourceRelationId(Long sourceRelationId) {
		this.sourceRelationId = sourceRelationId;
	}
	public Date getGmtCreate() {
		return gmtCreate;
	}
	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}
	public Date getGmtModified() {
		return gmtModified;
	}
	public void setGmtModified(Date gmtModified) {
		this.gmtModified = gmtModified;
	}
	public String getLimitScope() {
		return limitScope;
	}
	public void setLimitScope(String limitScope) {
		this.limitScope = limitScope;
	}
	public Integer getOperationsType() {
		return operationsType;
	}
	public void setOperationsType(Integer operationsType) {
		this.operationsType = operationsType;
	}
	public String getLimitTimeBetween() {
		return limitTimeBetween;
	}
	public void setLimitTimeBetween(String limitTimeBetween) {
		this.limitTimeBetween = limitTimeBetween;
	}
	public Integer getLimitEverydayQuantity() {
		return limitEverydayQuantity;
	}
	public void setLimitEverydayQuantity(Integer limitEverydayQuantity) {
		this.limitEverydayQuantity = limitEverydayQuantity;
	}
	public String getBannerImage() {
		return bannerImage;
	}
	public void setBannerImage(String bannerImage) {
		this.bannerImage = bannerImage;
	}
	public Long getVipLimits() {
		return vipLimits;
	}
	public void setVipLimits(Long vipLimits) {
		this.vipLimits = vipLimits;
	}
	public Integer getVipLimitType() {
		return vipLimitType;
	}
	public void setVipLimitType(Integer vipLimitType) {
		this.vipLimitType = vipLimitType;
	}

	public String getLimitDate() {
		return limitDate;
	}

	public void setLimitDate(String limitDate) {
		this.limitDate = limitDate;
	}

	public String getCustomTag() {
		return customTag;
	}

	public void setCustomTag(String customTag) {
		this.customTag = customTag;
	}

	public Integer getSubType() {
		return subType;
	}

	public void setSubType(Integer subType) {
		this.subType = subType;
	}

	public Date getAutoOffDate() {
		return autoOffDate;
	}

	public void setAutoOffDate(Date autoOffDate) {
		this.autoOffDate = autoOffDate;
	}

	public String getDevCustomCode() {
		return devCustomCode;
	}

	public void setDevCustomCode(String devCustomCode) {
		this.devCustomCode = devCustomCode;
	}

	public String getWhiteImage() {
		return whiteImage;
	}

	public void setWhiteImage(String whiteImage) {
		this.whiteImage = whiteImage;
	}

	public Long getSalePrice()
	{
		return salePrice;
	}

	public void setSalePrice(Long salePrice)
	{
		this.salePrice = salePrice;
	}

	public String getExpressType()
	{
		return expressType;
	}

	public void setExpressType(String expressType)
	{
		this.expressType = expressType;
	}

	public Long getExpressPrice()
	{
		return expressPrice;
	}

	public void setExpressPrice(Long expressPrice)
	{
		this.expressPrice = expressPrice;
	}

	public Long getExpressTemplateId()
	{
		return expressTemplateId;
	}

	public void setExpressTemplateId(Long expressTemplateId)
	{
		this.expressTemplateId = expressTemplateId;
	}
	
}

==> duiba-service-api-1.1-20160608.095249-126-sources.jar: cn/com/duiba/service/domain/dataobject/AppItemDO.java <==
package cn.com.duiba.service.domain.dataobject;

import cn.com.duiba.service.domain.BaseDO;

import java.util.Date;

public class AppItemDO extends BaseDO {
	private static final long serialVersionUID = 1231205L;
	public static final String StatusOn = "on";
	public static final String StatusOff = "off";
	public static final String SubStatusExpired = "expired"; // 子状态（expired：已过期）

	public static final String ExpressTypeFree = "free"; // 运费类型 包邮
	public static final String ExpressTypeUnity = "unity"; // 运费类型  统一运费
	public static final String ExpressTypeTemplate = "template"; // 运费类型 模板

	public static final int SourceTypeNormal = 0; // 普通兑换
	public static final int SourceTypeOperatingActivity = 1;// 运营活动创建的AppItem
	public static final int SourceTypeDuibaActivity = 2; //兑吧专题活动
	public static final int SourceTypeSingleLottery = 3;//单品抽奖活动
	public static final int SourceTypeManualLottery = 4;//手动开奖活动
	public static final int SourceTypeDuibaActivityItem = 5;// 专题活动的兑换项入口
	public static final int SourceTypeDuibaActivitySingleLottery = 6;// 专题活动的单品抽奖的兑换项入口
	public static final int SourceTypeAppShakeLottery = 7;//摇一摇抽奖
	public static final int SourceTypeAppScratchCardLottery = 8;//刮刮卡抽奖
	public static final int SourceTypeHdtoolTiger = 9;//老虎机
	public static final int SourceTypeHdtoolTurntable = 10;//活动工具大转盘
	public static final int SourceTypeSecondsKill = 11;//秒杀专题
	public static final int SourceTypeGameSanta = 20;//游戏，打劫圣诞老人
	public static final int SourceTypeGameYearAward = 21;//游戏，数年终奖
	public static final int SourceTypeGameGirl = 22;//游戏，女神pk
	public static final int SourceTypeGameJiong = 23;
	public static final int SourceTypeDuibaQuestionAnswer = 30;//兑吧答题活动
	public static final int SourceTypeDuibaQuizz = 41;//兑吧测试题活动
	public static final int SourceTypeDuibaSeckill = 40;//秒杀活动
	public static final int SourceTypeDuibaNgame = 28;//新游戏
	public static final int SourceTypeDuibaGuess = 42;//兑吧竞猜
	//会员等级限制类型,为0的话说明该兑换项没有配置会员等级限制
	public static final int OFF_LEVEL = 0;
	public static final int ACCURATE_LEVEL= 1;
	public static final int ABOVE_LEVEL = 2;
	
	//Start chaijiangang,幸运转盘改为活动工具,2016/04/12
	public static final String SourceTypeAppShakeLottery_Action = "shake";//摇一摇抽奖
	public static final String SourceTypeAppScratchCardLottery_Action = "ScratchCard";//刮刮卡抽奖
	public static final String SourceTypeHdtoolTiger_Action = "tiger";//老虎机
	public static final String SourceTypeHdtoolTurntable_Action = "turntableNew";//活动工具大转盘
	//End chaijiangang,幸运转盘改为活动工具,2016/04/12
	
	//Start guoeryang,开发者可编辑兑吧活动的抽奖积分,2016/05/03
	public static final int SwitchExchangeCreditsType = 16;//可编辑抽奖积分
	//End guoeryang,开发者可编辑兑吧活动的抽奖积分,2016/05/03  

	private Long id;
	private Long appId;
	private Long itemId;
	private Long batchId;
	private Long credits;
	private Integer minFacePrice;
	private String logo;
	private String title;
	private String subtitle;
	private Integer payload ;
	private String customPrice; // 用户自定义商品价格（可分为1-6栏显示，存储结构为json形式的字符串，
						// 面值1:积分1,面值2:积分2...）
	private Date addTime; // 商品加入开发者库的时间。
	private Boolean deleted; // 是否已经删除
	private String status; // 状态（on/off）
	private String subStatus; // 子状态（）
	private Boolean homeDisplay;// 是否首页展示
	private Boolean isOwner; // 是否开发者发布

	private String exchangeTipTemplate;// 兑换提示模板 实物用于 兑换成功文案
	private String alertMessage;//实物用于 待发货文案

	// --以下为自有实物字段
	private String description;
	private Integer facePrice;
	private Integer limitCount;
	private Integer remaining;
	private Date validEndDate;
	private String smallImage;
	private String whiteImage;
	private String image;

	private String multiImage;
	private String type;// 商品类型，比如 QB，话费充值 等等

	private Integer sourceType; // 来源类型，目前有 普通兑换类型，运营活动类型
	private Long sourceRelationId;//
	
	private String limitScope;
	private Integer operationsType;
	private String limitTimeBetween;
	private Integer limitEverydayQuantity;
	private String bannerImage;
	
	private String limitDate; //兑换日期限制
	private String customTag;
	private Integer subType;

	private Date gmtCreate;
	private Date gmtModified;
	
	//会员等级限制添加字段
	private Long vipLimits;
	private Integer vipLimitType;
	
	private Date autoOffDate; //定时自动下架日期
	
	private String devCustomCode;	// 开发者的商品ID
	
	private Long salePrice;//	兑换价格		 
	private String expressType;//	运费类型		free(包邮)，unity(统一运费)，template(运费模板)
	private Long expressPrice;//	运费价格		选择 统一价 或者 包邮
	private Long expressTemplateId;//	运费模板ID	L	选择 模板

    /**added zhengjy 20160520 安全链接 begin*/
    private Long sellerId;//商家id
    /**added zhengjy 20160520 安全链接 end*/
	
	public AppItemDO(boolean init4insert) {
		if (init4insert) {
			toBeInsert = true;
			facePrice = 0;
			isOwner = false;
			homeDisplay = true;
			deleted = false;
			sourceType = SourceTypeNormal;
			payload = 0;
			operationsType = 0;
			subStatus = "";
			gmtCreate = new Date();
			gmtModified = new Date();
			limitScope = ItemDO.LimitTypeForever;
			vipLimits = 0L;
			vipLimitType = 0;
		}
	}
	
	//Start chaijiangang,幸运转盘改为活动工具,2016/04/12
	public AppItemDO(Integer sourceType) {
		this.sourceType = sourceType;
	}
	//End chaijiangang,幸运转盘改为活动工具,2016/04/12

	public AppItemDO(Long id) {
		this.id = id;
		this.gmtModified = new Date();
		toBeUpdate = true;
	}

	public AppItemDO() {
	}

	public Long getSellerId() {
		return sellerId;
	}

	public void setSellerId(Long sellerId) {
		this.sellerId = sellerId;
	}
	
	public void beforeUpdate() {
		gmtModified = new Date();
	}
	
	public void grantOpTypeAppItem(int opType){
		int v=1<<opType;
		operationsType=operationsType | v;
	}
	
	public void ungrantOpTypeAppItem(int opType){
		int v=1<<opType;
		v=~v;
		operationsType=operationsType & v;
	}
	
	public boolean isOpTypeAppItem(int opType){
		int v=1<<opType;
		int ret= operationsType & v;
		return ret!=0;
	}
	
	public String getAlertMessage() {
		return alertMessage;
	}

	public void setAlertMessage(String alertMessage) {
		this.alertMessage = alertMessage;
	}

	public Long getId() {
		return id;
	}
	public void setId(Long id) {
		this.id = id;
	}
	public Long getAppId() {
		return appId;
	}
	public void setAppId(Long appId) {
		this.appId = appId;
	}
	public Long getItemId() {
		return itemId;
	}
	public void setItemId(Long itemId) {
		this.itemId = itemId;
	}
	public Long getBatchId() {
		return batchId;
	}
	public void setBatchId(Long batchId) {
		this.batchId = batchId;
	}
	public Long getCredits() {
		return credits;
	}
	public void setCredits(Long credits) {
		this.credits = credits;
	}
	public Integer getMinFacePrice() {
		return minFacePrice;
	}
	public void setMinFacePrice(Integer minFacePrice) {
		this.minFacePrice = minFacePrice;
	}
	public String getLogo() {
		return logo;
	}
	public void setLogo(String logo) {
		this.logo = logo;
	}
	public String getTitle() {
		return title;
	}
	public void setTitle(String title) {
		this.title = title;
	}
	public String getSubtitle() {
		return subtitle;
	}
	public void setSubtitle(String subtitle) {
		this.subtitle = subtitle;
	}
	public Integer getPayload() {
		return payload;
	}
	public void setPayload(Integer payload) {
		this.payload = payload;
	}
	public String getCustomPrice() {
		return customPrice;
	}
	public void setCustomPrice(String customPrice) {
		this.customPrice = customPrice;
	}
	public Date getAddTime() {
		return addTime;
	}
	public void setAddTime(Date addTime) {
		this.addTime = addTime;
	}
	public Boolean getDeleted() {
		return deleted;
	}
	public void setDeleted(Boolean deleted) {
		this.deleted = deleted;
	}
	public String getStatus() {
		return status;
	}
	public void setStatus(String status) {
		this.status = status;
	}
	public String getSubStatus() {
		return subStatus;
	}
	public void setSubStatus(String subStatus) {
		this.subStatus = subStatus;
	}
	public Boolean getHomeDisplay() {
		return homeDisplay;
	}
	public void setHomeDisplay(Boolean homeDisplay) {
		this.homeDisplay = homeDisplay;
	}
	public Boolean getIsOwner() {
		return isOwner;
	}
	public void setIsOwner(Boolean isOwner) {
		this.isOwner = isOwner;
	}
	public String getExchangeTipTemplate() {
		return exchangeTipTemplate;
	}
	public void setExchangeTipTemplate(String exchangeTipTemplate) {
		this.exchangeTipTemplate = exchangeTipTemplate;
	}
	public String getDescription() {
		return description;
	}
	public void setDescription(String description) {
		this.description = description;
	}
	public Integer getFacePrice() {
		return facePrice;
	}
	public void setFacePrice(Integer facePrice) {
		this.facePrice = facePrice;
	}
	public Integer getLimitCount() {
		return limitCount;
	}
	public void setLimitCount(Integer limitCount) {
		this.limitCount = limitCount;
	}
	public Integer getRemaining() {
		return remaining;
	}
	public void setRemaining(Integer remaining) {
		this.remaining = remaining;
	}
	public Date getValidEndDate() {
		return validEndDate;
	}
	public void setValidEndDate(Date validEndDate) {
		this.validEndDate = validEndDate;
	}
	public String getSmallImage() {
		return smallImage;
	}
	public void setSmallImage(String smallImage) {
		this.smallImage = smallImage;
	}
	public String getImage() {
		return image;
	}
	public void setImage(String image) {
		this.image = image;
	}
	public String getMultiImage() {
		return multiImage;
	}
	public void setMultiImage(String multiImage) {
		this.multiImage = multiImage;
	}
	public String getType() {
		return type;
	}
	public void setType(String type) {
		this.type = type;
	}
	public Integer getSourceType() {
		return sourceType;
	}
	public void setSourceType(Integer sourceType) {
		this.sourceType = sourceType;
	}
	public Long getSourceRelationId() {
		return sourceRelationId;
	}
	public void setSourceRelationId(Long sourceRelationId) {
		this.sourceRelationId = sourceRelationId;
	}
	public Date getGmtCreate() {
		return gmtCreate;
	}
	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}
	public Date getGmtModified() {
		return gmtModified;
	}
	public void setGmtModified(Date gmtModified) {
		this.gmtModified = gmtModified;
	}
	public String getLimitScope() {
		return limitScope;
	}
	public void setLimitScope(String limitScope) {
		this.limitScope = limitScope;
	}
	public Integer getOperationsType() {
		return operationsType;
	}
	public void setOperationsType(Integer operationsType) {
		this.operationsType = operationsType;
	}
	public String getLimitTimeBetween() {
		return limitTimeBetween;
	}
	public void setLimitTimeBetween(String limitTimeBetween) {
		this.limitTimeBetween = limitTimeBetween;
	}
	public Integer getLimitEverydayQuantity() {
		return limitEverydayQuantity;
	}
	public void setLimitEverydayQuantity(Integer limitEverydayQuantity) {
		this.limitEverydayQuantity = limitEverydayQuantity;
	}
	public String getBannerImage() {
		return bannerImage;
	}
	public void setBannerImage(String bannerImage) {
		this.bannerImage = bannerImage;
	}
	public Long getVipLimits() {
		return vipLimits;
	}
	public void setVipLimits(Long vipLimits) {
		this.vipLimits = vipLimits;
	}
	public Integer getVipLimitType() {
		return vipLimitType;
	}
	public void setVipLimitType(Integer vipLimitType) {
		this.vipLimitType = vipLimitType;
	}

	public String getLimitDate() {
		return limitDate;
	}

	public void setLimitDate(String limitDate) {
		this.limitDate = limitDate;
	}

	public String getCustomTag() {
		return customTag;
	}

	public void setCustomTag(String customTag) {
		this.customTag = customTag;
	}

	public Integer getSubType() {
		return subType;
	}

	public void setSubType(Integer subType) {
		this.subType = subType;
	}

	public Date getAutoOffDate() {
		return autoOffDate;
	}

	public void setAutoOffDate(Date autoOffDate) {
		this.autoOffDate = autoOffDate;
	}

	public String getDevCustomCode() {
		return devCustomCode;
	}

	public void setDevCustomCode(String devCustomCode) {
		this.devCustomCode = devCustomCode;
	}

	public String getWhiteImage() {
		return whiteImage;
	}

	public void setWhiteImage(String whiteImage) {
		this.whiteImage = whiteImage;
	}

	public Long getSalePrice()
	{
		return salePrice;
	}

	public void setSalePrice(Long salePrice)
	{
		this.salePrice = salePrice;
	}

	public String getExpressType()
	{
		return expressType;
	}

	public void setExpressType(String expressType)
	{
		this.expressType = expressType;
	}

	public Long getExpressPrice()
	{
		return expressPrice;
	}

	public void setExpressPrice(Long expressPrice)
	{
		this.expressPrice = expressPrice;
	}

	public Long getExpressTemplateId()
	{
		return expressTemplateId;
	}

	public void setExpressTemplateId(Long expressTemplateId)
	{
		this.expressTemplateId = expressTemplateId;
	}
	
	//Start chaijiangang,幸运转盘改为活动工具,2016/04/12
	public String getPreviewAction() {
		switch (this.sourceType) {
		case SourceTypeAppShakeLottery: // 摇一摇 ok
			return SourceTypeAppShakeLottery_Action;
		case SourceTypeAppScratchCardLottery: // 刮刮卡 ok
			return SourceTypeAppScratchCardLottery_Action;
		case SourceTypeHdtoolTurntable: // 活动工具大转盘 ok
			return SourceTypeHdtoolTurntable_Action;
		case SourceTypeHdtoolTiger: // 老虎机 ok
			return SourceTypeHdtoolTiger_Action;
		default:
			return "";
		}
	}
	
	public boolean isHdTool(){
		if(this.sourceType == SourceTypeAppShakeLottery
				|| this.sourceType == SourceTypeHdtoolTiger
				|| this.sourceType == SourceTypeAppScratchCardLottery
				|| this.sourceType == SourceTypeHdtoolTurntable)
			return true;
		else return false;
	}
	//End chaijiangang,幸运转盘改为活动工具,2016/04/12
	
}
